@@ -34,13 +34,13 @@ class TabbedViewWidgetModel : public QAbstractItemModel
     Q_OBJECT
 public:
     explicit TabbedViewWidgetModel(QTabWidget *modelTarget);
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
-    QModelIndex parent(const QModelIndex &index) const;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
-    bool setData(const QModelIndex &index, const QVariant &value, int role);
-    QVariant data(const QModelIndex &index, int role) const;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &index) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
+    QVariant data(const QModelIndex &index, int role) const override;
 protected:
     void emitLayoutAboutToBeChanged();
     void emitLayoutChanged();
@@ -54,8 +54,8 @@ class TabbedViewWidget : public QTabWidget
 {
     Q_OBJECT
 public:
-    explicit TabbedViewWidget(QWidget *parent = 0);
-    virtual ~TabbedViewWidget();
+    explicit TabbedViewWidget(QWidget *parent = nullptr);
+    ~TabbedViewWidget() override;
     TabbedViewWidgetModel* getModel();
     int addTab(QWidget *page, const QString &label);
     int addTab(QWidget *page, const QIcon &icon, const QString &label);
